@@ -27,6 +27,7 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #ifndef _XKBSTR_H_
 #define	_XKBSTR_H_
 
+#include <X11/Xfuncproto.h>
 #include <X11/extensions/XKB.h>
 
 #define	XkbCharToInt(v)		((v)&0x80?(int)((v)|(~0xff)):(int)((v)&0x7f))
@@ -401,12 +402,12 @@ typedef struct _XkbIndicatorRec {
 } XkbIndicatorRec,*XkbIndicatorPtr;
 
 typedef	struct _XkbKeyNameRec {
-	char	name[XkbKeyNameLength];
+	char	name[XkbKeyNameLength]	_X_NONSTRING;
 } XkbKeyNameRec,*XkbKeyNamePtr;
 
 typedef struct _XkbKeyAliasRec {
-	char	real[XkbKeyNameLength];
-	char	alias[XkbKeyNameLength];
+	char	real[XkbKeyNameLength]	_X_NONSTRING;
+	char	alias[XkbKeyNameLength]	_X_NONSTRING;
 } XkbKeyAliasRec,*XkbKeyAliasPtr;
 
 	/*
